@@ -29,10 +29,11 @@
 #include "tracker-namespace.h"
 #include "tracker-ontologies.h"
 
-#define GET_PRIV(obj) (((TrackerClass*) obj)->priv)
-#define TRACKER_CLASS_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), TRACKER_TYPE_CLASS, TrackerClassPrivate))
+#define GET_PRIV(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), TRACKER_TYPE_CLASS, TrackerClassPriv))
 
-struct _TrackerClassPrivate {
+typedef struct _TrackerClassPriv TrackerClassPriv;
+
+struct _TrackerClassPriv {
 	gchar *uri;
 	gchar *name;
 	gint count;
@@ -53,27 +54,24 @@ tracker_class_class_init (TrackerClassClass *klass)
 
 	object_class->finalize     = class_finalize;
 
-	g_type_class_add_private (object_class, sizeof (TrackerClassPrivate));
+	g_type_class_add_private (object_class, sizeof (TrackerClassPriv));
 }
 
 static void
 tracker_class_init (TrackerClass *service)
 {
-	TrackerClassPrivate *priv;
+	TrackerClassPriv *priv;
 
-	priv = TRACKER_CLASS_GET_PRIVATE (service);
+	priv = GET_PRIV (service);
 
 	priv->id = 0;
 	priv->super_classes = g_array_new (TRUE, TRUE, sizeof (TrackerClass *));
-
-	/* Make GET_PRIV working */
-	service->priv = priv;
 }
 
 static void
 class_finalize (GObject *object)
 {
-	TrackerClassPrivate *priv;
+	TrackerClassPriv *priv;
 
 	priv = GET_PRIV (object);
 
@@ -98,7 +96,7 @@ tracker_class_new (void)
 const gchar *
 tracker_class_get_uri (TrackerClass *service)
 {
-	TrackerClassPrivate *priv;
+	TrackerClassPriv *priv;
 
 	g_return_val_if_fail (TRACKER_IS_CLASS (service), NULL);
 
@@ -110,7 +108,7 @@ tracker_class_get_uri (TrackerClass *service)
 const gchar *
 tracker_class_get_name (TrackerClass *service)
 {
-	TrackerClassPrivate *priv;
+	TrackerClassPriv *priv;
 
 	g_return_val_if_fail (TRACKER_IS_CLASS (service), NULL);
 
@@ -122,7 +120,7 @@ tracker_class_get_name (TrackerClass *service)
 gint
 tracker_class_get_count (TrackerClass *service)
 {
-	TrackerClassPrivate *priv;
+	TrackerClassPriv *priv;
 
 	g_return_val_if_fail (TRACKER_IS_CLASS (service), 0);
 
@@ -134,7 +132,7 @@ tracker_class_get_count (TrackerClass *service)
 gint
 tracker_class_get_id (TrackerClass *service)
 {
-	TrackerClassPrivate *priv;
+	TrackerClassPriv *priv;
 
 	g_return_val_if_fail (TRACKER_IS_CLASS (service), 0);
 
@@ -146,7 +144,7 @@ tracker_class_get_id (TrackerClass *service)
 TrackerClass **
 tracker_class_get_super_classes (TrackerClass *service)
 {
-	TrackerClassPrivate *priv;
+	TrackerClassPriv *priv;
 
 	g_return_val_if_fail (TRACKER_IS_CLASS (service), NULL);
 
@@ -158,7 +156,7 @@ tracker_class_get_super_classes (TrackerClass *service)
 gboolean
 tracker_class_get_is_new (TrackerClass *service)
 {
-	TrackerClassPrivate *priv;
+	TrackerClassPriv *priv;
 
 	g_return_val_if_fail (TRACKER_IS_CLASS (service), FALSE);
 
@@ -171,7 +169,7 @@ void
 tracker_class_set_uri (TrackerClass *service,
                        const gchar  *value)
 {
-	TrackerClassPrivate *priv;
+	TrackerClassPriv *priv;
 
 	g_return_if_fail (TRACKER_IS_CLASS (service));
 
@@ -212,7 +210,7 @@ void
 tracker_class_set_count (TrackerClass *service,
                          gint          value)
 {
-	TrackerClassPrivate *priv;
+	TrackerClassPriv *priv;
 
 	g_return_if_fail (TRACKER_IS_CLASS (service));
 
@@ -226,7 +224,7 @@ void
 tracker_class_set_id (TrackerClass *service,
                       gint          value)
 {
-	TrackerClassPrivate *priv;
+	TrackerClassPriv *priv;
 
 	g_return_if_fail (TRACKER_IS_CLASS (service));
 
@@ -240,7 +238,7 @@ void
 tracker_class_add_super_class (TrackerClass *service,
                                TrackerClass *value)
 {
-	TrackerClassPrivate *priv;
+	TrackerClassPriv *priv;
 
 	g_return_if_fail (TRACKER_IS_CLASS (service));
 	g_return_if_fail (TRACKER_IS_CLASS (value));
@@ -254,7 +252,7 @@ void
 tracker_class_set_is_new (TrackerClass *service,
                           gboolean         value)
 {
-	TrackerClassPrivate *priv;
+	TrackerClassPriv *priv;
 
 	g_return_if_fail (TRACKER_IS_CLASS (service));
 
