@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2009, Nokia
+ * Copyright (C) 2009, Nokia <ivan.frade@nokia.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -1144,3 +1144,11 @@ tracker_db_journal_reader_get_statement_id (gint *g_id,
 
 	return TRUE;
 }
+
+gdouble
+tracker_db_journal_reader_get_progress (void)
+{
+	gdouble percent = ((gdouble)(reader.end - reader.start));
+	return ((gdouble)(reader.current - reader.start)) / percent;
+}
+
