@@ -29,7 +29,6 @@
 #include <sys/types.h>
 #include <stdio.h>
 #include <fcntl.h>
-#include <errno.h>
 
 #include <glib/gstdio.h>
 
@@ -52,14 +51,11 @@
 #define TRACKER_DB_PAGE_SIZE_DONT_SET -1
 
 /* Set current database version we are working with */
-#define TRACKER_DB_VERSION_NOW        TRACKER_DB_VERSION_0_8_0
+#define TRACKER_DB_VERSION_NOW        TRACKER_DB_VERSION_0_9_0
 #define TRACKER_DB_VERSION_FILE       "db-version.txt"
 
 #define IN_USE_FILENAME               ".meta.isrunning"
 
-/* Stamp filename to check for first index */
-#define FIRST_INDEX_STAMP_FILENAME    ".firstindex"
-
 typedef enum {
 	TRACKER_DB_LOCATION_DATA_DIR,
 	TRACKER_DB_LOCATION_USER_DATA_DIR,
@@ -403,10 +399,7 @@ db_manager_remove_all (gboolean rm_journal)
 {
 	guint i;
 
-	g_message ("Removing all database/storage files");
-
-	/* Remove stamp file */
-	tracker_db_manager_set_first_index_done (FALSE);
+	g_message ("Removing all database files");
 
 	/* NOTE: We don't have to be initialized for this so we
 	 * calculate the absolute directories here.
@@ -626,6 +619,10 @@ tracker_db_manager_init_locations (void)
 	for (i = 1; i < G_N_ELEMENTS (dbs); i++) {
 		dir = location_to_directory (dbs[i].location);
 		dbs[i].abs_filename = g_build_filename (dir, dbs[i].file, NULL);
+
+		if (old_flags & TRACKER_DB_MANAGER_LOW_MEMORY_MODE) {
+			dbs[i].cache_size /= 2;
+		}
 	}
 
 	locations_initialized = TRUE;
@@ -735,6 +732,10 @@ tracker_db_manager_init (TrackerDBManagerFlags  flags,
 			g_free (dbs[i].abs_filename);
 		dbs[i].abs_filename = g_build_filename (dir, dbs[i].file, NULL);
 
+		if (flags & TRACKER_DB_MANAGER_LOW_MEMORY_MODE) {
+			dbs[i].cache_size /= 2;
+		}
+
 		/* Check we have each database in place, if one is
 		 * missing, we reindex.
 		 */
@@ -788,9 +789,6 @@ tracker_db_manager_init (TrackerDBManagerFlags  flags,
 			return FALSE;
 		}
 
-		/* Clear the first-index stamp file */
-		tracker_db_manager_set_first_index_done (FALSE);
-
 		db_recreate_all ();
 
 		/* Load databases */
@@ -881,12 +879,8 @@ tracker_db_manager_init (TrackerDBManagerFlags  flags,
 	in_use_file = g_open (in_use_filename,
 	                      O_WRONLY | O_APPEND | O_CREAT | O_SYNC,
 	                      S_IRUSR | S_IWUSR | S_IRGRP | S_IWGRP);
-
-        if (in_use_file >= 0) {
-                fsync (in_use_file);
-                close (in_use_file);
-        }
-
+	fsync (in_use_file);
+	close (in_use_file);
 	g_free (in_use_filename);
 
 	tracker_db_manager_ensure_locale ();
@@ -1209,79 +1203,3 @@ tracker_db_manager_has_enough_space  (void)
 {
 	return tracker_file_system_has_enough_space (data_dir, TRACKER_DB_MIN_REQUIRED_SPACE, FALSE);
 }
-
-static gchar *
-get_first_index_stamp_path (void)
-{
-	return g_build_filename (g_get_user_cache_dir (),
-	                         "tracker",
-	                         FIRST_INDEX_STAMP_FILENAME,
-	                         NULL);
-}
-
-/**
- * tracker_db_manager_get_first_index_done:
- *
- * Check if first full index of files was already done.
- *
- * Returns: %TRUE if a first full index have been done, %FALSE otherwise.
- **/
-gboolean
-tracker_db_manager_get_first_index_done (void)
-{
-	gboolean exists;
-	gchar *stamp;
-
-	stamp = get_first_index_stamp_path();
-	exists = g_file_test (stamp, G_FILE_TEST_EXISTS);
-	g_free (stamp);
-
-	return exists;
-}
-
-/**
- * tracker_db_manager_set_first_index_done:
- *
- * Set the status of the first full index of files. Should be set to
- *  %FALSE if the index was never done or if a reindex is needed. When
- *  the index is completed, should be set to %TRUE.
- **/
-void
-tracker_db_manager_set_first_index_done (gboolean done)
-{
-	gboolean already_exists;
-	gchar *stamp;
-
-	stamp = get_first_index_stamp_path ();
-
-	already_exists = g_file_test (stamp, G_FILE_TEST_EXISTS);
-
-	if (done && !already_exists) {
-		GError *error = NULL;
-
-		/* If done, create stamp file if not already there */
-		if (!g_file_set_contents (stamp, "", -1, &error)) {
-			g_warning ("  Creating first-index stamp in "
-			           "'%s' failed: '%s'",
-			           stamp,
-			           error->message);
-			g_error_free (error);
-		} else {
-			g_message ("  First-index stamp created in '%s'",
-			           stamp);
-		}
-	} else if (!done && already_exists) {
-		/* If NOT done, remove stamp file */
-		if (g_remove (stamp)) {
-			g_warning ("  Removing first-index stamp from '%s' "
-			           "failed: '%s'",
-			           stamp,
-			           g_strerror (errno));
-		} else {
-			g_message ("  First-index stamp removed from '%s'",
-			           stamp);
-		}
-	}
-
-	g_free (stamp);
-}
