@@ -23,9 +23,6 @@
 #include <libtracker-extract/tracker-extract.h>
 
 #include "tracker-main.h"
-#include "tracker-gsf.h"
-
-#include <unistd.h>
 
 typedef enum {
 	ODT_TAG_TYPE_UNKNOWN,
@@ -69,106 +66,29 @@ static TrackerExtractData extract_data[] = {
 	{ NULL, NULL }
 };
 
-
-#define ODT_BUFFER_SIZE            8193  /* bytes */
-
 static gchar *
-extract_oasis_content (const gchar *uri,
-                       guint        n_words,
-                       gsize        n_bytes)
+extract_content (const gchar *path,
+                 guint        n_words)
 {
-	const gchar *argv[4];
-	gint fdz;
-	FILE *fz;
+	gchar *command, *output, *text;
 	GError *error = NULL;
-	gchar *text = NULL;
-	gchar *path;
 
-	/* Newly allocated string with the file path */
-	path = g_filename_from_uri (uri, NULL, NULL);
+	command = g_strdup_printf ("odt2txt --encoding=utf-8 '%s'", path);
+	g_debug ("Executing command:'%s'", command);
 
-	/* Setup command to be executed */
-	argv[0] = "odt2txt";
-	argv[1] = "--encoding=utf-8";
-	argv[2] = path;
-	argv[3] = NULL;
+	if (!g_spawn_command_line_sync (command, &output, NULL, NULL, &error)) {
+		g_warning ("Could not extract text from '%s': %s", path, error->message);
+		g_error_free (error);
+		g_free (command);
 
-	g_debug ("Executing command:'%s %s %s' (max words: %u, "
-	         "max_bytes: %" G_GSIZE_FORMAT ")",
-	         argv[0], argv[1], argv[2], n_words, n_bytes);
-
-	/* Fork & spawn */
-	if (!g_spawn_async_with_pipes (g_get_tmp_dir (),
-	                               (gchar **)argv,
-	                               NULL,
-	                               G_SPAWN_SEARCH_PATH | G_SPAWN_STDERR_TO_DEV_NULL,
-	                               tracker_spawn_child_func,
-	                               GINT_TO_POINTER (10),
-	                               NULL,
-	                               NULL,
-	                               &fdz,
-	                               NULL,
-	                               &error)) {
-		g_warning ("Spawning failed, could not extract text from '%s': %s",
-		           path, error ? error->message : NULL);
-		g_clear_error (&error);
-	}
-	/* Open file descriptor for reading */
-	else if ((fz = fdopen (fdz, "r")) == NULL) {
-		g_warning ("Cannot read child's output... could not extract "
-		           "text from '%s'", path);
-		close (fdz);
-	}
-	/* Start buffered reading... */
-	else {
-		unsigned char buf[ODT_BUFFER_SIZE];
-		size_t r, accum;
-		guint n_words_remaining = n_words;
-		GString *normalized;
-
-		accum = 0;
-		normalized = g_string_new ("");
-
-		/* Reading in chunks of ODT_BUFFER_SIZE -1 (8192)
-		 *   Loop is halted whenever one of this conditions is met:
-		 *     a) Read bytes reached the maximum allowed (n_bytes)
-		 *     b) Already read up to the max number of words configured
-		 *     c) No more bytes to read
-		 */
-		while ((accum <= n_bytes) &&
-		       (n_words_remaining > 0) &&
-		       (r = fread (buf, 1, ODT_BUFFER_SIZE-1, fz))) {
-			gchar *normalized_chunk;
-			guint n_words_normalized;
-
-			/* Always make sure that the read string will be
-			 * NIL-terminated  */
-			buf[r] = '\0';
-			/* Get normalized chunk */
-			normalized_chunk = tracker_text_normalize (buf,
-			                                           n_words_remaining,
-			                                           &n_words_normalized);
-			/* Update number of words remaining.
-			 * Note that n_words_normalized should always be less or
-			 * equal than n_words_remaining */
-			n_words_remaining = (n_words_normalized <= n_words_remaining ?
-			                     n_words_remaining - n_words_normalized : 0);
-			/* Update accumulated */
-			accum += r;
-
-			/* Add normalized chunk to the whole normalized string */
-			g_string_append (normalized, normalized_chunk);
-			g_free (normalized_chunk);
-		}
-
-		/* fclose() the stream, no need to close() the original FD */
-		fclose (fz);
-
-		/* Set final normalized contents to return */
-		text = g_string_free (normalized, FALSE);
+		return NULL;
 	}
 
-	g_free (path);
+	g_debug ("Normalizing output with %d max words", n_words);
+	text = tracker_text_normalize (output, n_words, NULL);
+
+	g_free (command);
+	g_free (output);
 
 	return text;
 }
@@ -178,60 +98,63 @@ extract_oasis (const gchar          *uri,
                TrackerSparqlBuilder *preupdate,
                TrackerSparqlBuilder *metadata)
 {
+	gchar *argv[5];
+	gchar *xml;
+	gchar *filename;
 	gchar *content;
 	TrackerFTSConfig *fts_config;
 	guint n_words;
-	gsize n_bytes;
-	ODTParseInfo info;
-	GMarkupParseContext *context;
-	GMarkupParser parser = {
-		xml_start_element_handler,
-		xml_end_element_handler,
-		xml_text_handler,
-		NULL,
-		NULL
-	};
 
-	/* Setup conf */
-	fts_config = tracker_main_get_fts_config ();
+	filename = g_filename_from_uri (uri, NULL, NULL);
 
-	g_debug ("Extracting OASIS metadata and contents from '%s'", uri);
+	argv[0] = g_strdup ("unzip");
+	argv[1] = g_strdup ("-p");
+	argv[2] = filename;
+	argv[3] = g_strdup ("meta.xml");
+	argv[4] = NULL;
 
-	/* First, parse metadata */
+	/* Question: shouldn't we g_unlink meta.xml then? */
 
 	tracker_sparql_builder_predicate (metadata, "a");
 	tracker_sparql_builder_object (metadata, "nfo:PaginatedTextDocument");
 
-	/* Create parse info */
-	info.metadata = metadata;
-	info.current = ODT_TAG_TYPE_UNKNOWN;
-	info.uri = uri;
+	if (tracker_spawn (argv, 10, &xml, NULL)) {
+		ODTParseInfo info;
+		GMarkupParseContext *context;
+		GMarkupParser parser = {
+			xml_start_element_handler,
+			xml_end_element_handler,
+			xml_text_handler,
+			NULL,
+			NULL
+		};
 
-	/* Create parsing context */
-	context = g_markup_parse_context_new (&parser, 0, &info, NULL);
+		info.metadata = metadata;
+		info.current = ODT_TAG_TYPE_UNKNOWN;
+		info.uri = uri;
 
-	/* Load the internal XML file from the Zip archive, and parse it
-	 * using the given context */
-	tracker_gsf_parse_xml_in_zip (uri, "meta.xml", context);
-	g_markup_parse_context_free (context);
+		context = g_markup_parse_context_new (&parser, 0, &info, NULL);
+		g_markup_parse_context_parse (context, xml, -1, NULL);
 
-	/* Next, parse contents */
+		g_markup_parse_context_free (context);
+		g_free (xml);
+	}
 
-	/* Set max words to read from content */
+	fts_config = tracker_main_get_fts_config ();
 	n_words = tracker_fts_config_get_max_words_to_index (fts_config);
+	content = extract_content (filename, n_words);
 
-	/* Set max bytes to read from content.
-	 * Assuming 3 bytes per unicode point in UTF-8, as 4-byte UTF-8 unicode
-	 *  points are really pretty rare */
-	n_bytes = 3 * n_words * tracker_fts_config_get_max_word_length(fts_config);
-
-	/* Extract content with the given limitations */
-	content = extract_oasis_content (uri, n_words, n_bytes);
 	if (content) {
 		tracker_sparql_builder_predicate (metadata, "nie:plainTextContent");
 		tracker_sparql_builder_object_unvalidated (metadata, content);
 		g_free (content);
 	}
+
+	g_free (argv[3]);
+	g_free (argv[1]);
+	g_free (argv[0]);
+
+	g_free (filename);
 }
 
 static void
@@ -336,7 +259,7 @@ xml_text_handler (GMarkupParseContext  *context,
 
 		keywords = g_strdup (text);
 
-		for (keyw = strtok_r (keywords, ",; ", &lasts);
+		for (keyw = strtok_r (keywords, ",; ", &lasts); 
 		     keyw;
 		     keyw = strtok_r (NULL, ",; ", &lasts)) {
 			tracker_sparql_builder_predicate (metadata, "nie:keyword");
